# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class RespeecherEnvironment:
    PUBLIC_EN_RT: RespeecherEnvironment

    def __init__(self, *, base: str, ws: str):
        self.base = base
        self.ws = ws


RespeecherEnvironment.PUBLIC_EN_RT = RespeecherEnvironment(
    base="https://api.respeecher.com/v1/public/tts/en-rt", ws="wss://api.respeecher.com/v1/public/tts/en-rt"
)
