# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions


class Response_ChunkParams(typing_extensions.TypedDict):
    type: typing.Literal["chunk"]
    context_id: str
    data: str


class Response_DoneParams(typing_extensions.TypedDict):
    type: typing.Literal["done"]
    context_id: str


class Response_ErrorParams(typing_extensions.TypedDict):
    type: typing.Literal["error"]
    error: str
    status_code: int
    context_id: typing_extensions.NotRequired[str]


ResponseParams = typing.Union[Response_ChunkParams, Response_DoneParams, Response_ErrorParams]
