# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class OutputFormatParams(typing_extensions.TypedDict):
    sample_rate: typing_extensions.NotRequired[int]
    """
    Audio sample rate, defaults to 22050.
    """
