# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .gender import Gender
from .sampling_params import SamplingParams
from .voice import Voice

__all__ = ["Gender", "SamplingParams", "Voice"]
