# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from .streaming_generation_request import StreamingGenerationRequestParams


class ContextfulGenerationRequestParams(StreamingGenerationRequestParams):
    context_id: str
    """
    Use different context IDs for different generations over one WebSocket connection.
    """

    continue_: typing_extensions.NotRequired[typing_extensions.Annotated[bool, FieldMetadata(alias="continue")]]
    """
    Set to `true` for smooth prosody if text is streamed in chunks and this is not the last chunk.
    """
