# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.streaming_encoding import StreamingEncoding
from .output_format import OutputFormatParams


class StreamingOutputFormatParams(OutputFormatParams):
    encoding: typing_extensions.NotRequired[StreamingEncoding]
